Metric Generators
=================

.. toctree::

    stonesoup.metricgenerator.basicmetrics
    stonesoup.metricgenerator.tracktotruthmetrics
    stonesoup.metricgenerator.ospametric
    stonesoup.metricgenerator.uncertaintymetric

.. automodule:: stonesoup.metricgenerator
    :no-members:

.. automodule:: stonesoup.metricgenerator.base
    :show-inheritance:

Metric Managers
---------------
.. automodule:: stonesoup.metricgenerator.manager
